Stan Math Library: stan/math/rev/mat/fun/log_determinant_spd.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
log_determinant_spd.hpp File Reference
`#include <boost/math/special_functions/fpclassify.hpp>`
`#include <stan/math/prim/scal/err/domain_error.hpp>`
`#include <stan/math/prim/mat/err/check_square.hpp>`
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <stan/math/rev/core.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<int R, int C>
var | stan::math::log_determinant_spd (const Eigen::Matrix< var, R, C > &m)

[ Stan Home Page ] © 2011–2016, Stan Development Team.